//+------------------------------------------------------------------+
//|                                              RSX Swinger 1p3.mq4 |
//|                                                         Scorpion |
//|                                              www.fxfisherman.com |
//+------------------------------------------------------------------+
#property copyright "Scorpion"
#property link      "www.fxfisherman.com"
#define MagicRSXSwinger  19790510



//---- input parameters
extern string    ExpertName = "RSX Swinger";
extern int       RSXPeriod=10;
extern double    BuyLevel=51.0;
extern double    SellLevel=49.0;
extern double    LotsSize=1;
extern int       SL=30;
extern int       TP=20;
extern int       MaxEntrySlippage=5;
extern int       MaxExitSlippage=10;

//---- local variables
int PreviousPosition=0;

//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
{
  return(0);
}
  
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
{
  return(0);
}
  
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{
  
  // Calculate RSXs
  double rsx0 = iCustom(Symbol(),Period(),"RSX",RSXPeriod,0,0);
  double rsx1 = iCustom(Symbol(),Period(),"RSX",RSXPeriod,0,1);
  Comment("RSX Previous = " + rsx1 + "\nRSX Current = " + rsx0) ;
  
  // Analyse
  bool IsBuy = (rsx1 <= BuyLevel && rsx0 > BuyLevel);
  bool IsSell = (rsx1 >= SellLevel && rsx0 < SellLevel);

  // Close existed trades
  if (CanExit())
  {
    if (IsBuy)
    {
      CloseSold();
    }else if (IsSell){
      CloseBought();
    }
  }
   
  // Enter new trade
  if (CanEnter())
  {
    if (IsBuy)
    {
      BuyIt();
    }else if (IsSell){
      SellIt();
    }
  }

  return(0);
}
  
//+------------------------------------------------------------------+
//| Close bought trades                                              |
//+------------------------------------------------------------------+
bool CloseBought()
{
  for(int i=0;i<OrdersTotal();i++)
  {
    if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
    if(OrderMagicNumber()==MagicRSXSwinger && OrderType()==OP_BUY)
    {
      bool ret = OrderClose(OrderTicket(),OrderLots(),Bid,MaxExitSlippage*Point);
      if (ret)
      {
        Alert(ExpertName + " CLOSED Order#" + OrderTicket());
      }else{
        Alert(ExpertName + " CLOSE FAILED.");
      }
      return(ret);
    }
  }

}

//+------------------------------------------------------------------+
//| Close sold trades                                                |
//+------------------------------------------------------------------+
bool CloseSold()
{
  for(int i=0;i<OrdersTotal();i++)
  {
    if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
    if(OrderMagicNumber()==MagicRSXSwinger && OrderType()==OP_SELL)
    {
      bool ret = OrderClose(OrderTicket(),OrderLots(),Ask,MaxExitSlippage*Point);
      if (ret)
      {
        Alert(ExpertName + " CLOSED Order#" + OrderTicket());
      }else{
        Alert(ExpertName + " CLOSE FAILED.");
      }
      return(ret);
    }
  }
}

//+------------------------------------------------------------------+
//| Buy                                                              |
//+------------------------------------------------------------------+
int BuyIt()
{

  // Check
  if (PreviousPosition == 1) return(0);
  
  // Calculate true SL/TP
  double TrueSL, TrueTP;
  if (SL > 0) TrueSL = Ask-(SL*Point);
  if (TP > 0) TrueTP = Ask+(TP*Point);
  
  // Send order
  int ret = OrderSend(Symbol(),OP_BUY,LotsSize,Ask,MaxEntrySlippage*Point,TrueSL,TrueTP,NULL,MagicRSXSwinger);
  
  // Notify user
  if (ret != -1)
  {
    PreviousPosition = 1;
    Alert(ExpertName + " LONG " + Symbol() + " " + LotsSize + " lots at ASK = " + Ask + ". Ticket #" + ret);
  }else{
    Alert(ExpertName + " LONG FAILED " + Symbol() + ".");
  }
  return(ret);
  
}

//+------------------------------------------------------------------+
//| Sell                                                             |
//+------------------------------------------------------------------+
int SellIt()
{

  // Check
  if (PreviousPosition == -1) return(0);
  
  // Calculate true SL/TP
  double TrueSL, TrueTP;
  if (SL > 0) TrueSL = Bid+(SL*Point);
  if (TP > 0) TrueTP = Bid-(TP*Point);
  
  // Send order
  int ret = OrderSend(Symbol(),OP_SELL,LotsSize,Bid,MaxEntrySlippage*Point,TrueSL,TrueTP,NULL,MagicRSXSwinger);
  
  // Notify user
  if (ret >= 0)
  {
    PreviousPosition = -1;
    Alert(ExpertName + " SHORT " + Symbol() + " " + LotsSize + " lots at BID = " + Bid + ". Ticket #" + ret);
  }else{
    Alert(ExpertName + " SHORT FAILED " + Symbol() + ".");
  }
  return(ret);
  
}

//+------------------------------------------------------------------+
//| Check if possible to enter new trade                             |
//+------------------------------------------------------------------+
bool CanEnter()
{
  if (IsTradeAllowed())
  {
    for(int i=0;i<OrdersTotal();i++)
    {
       if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
       if(OrderMagicNumber()==MagicRSXSwinger)
       {
          return(false);
       }
    }
    return(true);
  }
}

//+------------------------------------------------------------------+
//| Check if possible to close existed trades                        |
//+------------------------------------------------------------------+
bool CanExit()
{
  if (IsTradeAllowed())
  {
    if (OrdersTotal() > 0) return(true);
  }
}


//+--------------------------Scorpion--------------------------------+